Editor Integration
------------------

If your editor can execute programs on the command line, you can run VSG without having to leave your editor.
This brings a new level of efficiency to coding in VHDL.

.. toctree::
   :maxdepth: 2

   vim.rst
   vscode.rst
